@@ -8,6 +8,8 @@ class HiddenFieldBlock(BaseFieldBlock):
     default_value = blocks.CharBlock(
         max_length=255,
         required=True,
+        label='Value',
+        help_text='The value to go into the hidden field.'
     )
 
     choices = None
@@ -28,6 +30,8 @@ class HiddenFieldBlock(BaseFieldBlock):
 
     placeholder = None
 
+    rules = None
+
     class Meta:
         form_classname = 'waf--field'
         icon = 'extraicons--hidden'
